from unicodedata import name
from setuptools import setup, find_packages

classifiers = [
    'Development Status :: 5 - Production/Stable',
    'Intended Audience :: Education',
    'Operating System :: Microsoft :: Windows :: Windows 10',
    'License :: OSI Approved :: MIT License',
    'Programming Language :: Python :: 3'
 
]

setup(
    name='bizchat',
    version='4.0.0',
    description='import this library to use chat from client to  server directly',
    long_description=open('README.txt').read() + '\n\n',
    url='',
    author='mayur', 
    author_email='mayurdhameliya98@gmai.com',
    license='MIT',
    classifiers=classifiers,
    keywords='server client,chatapp',
    packages=find_packages(),
    install_requires=['']
    
)







from socket import socket
import socket


def server():
    hostname = socket.gethostname()
    local_ip = socket.gethostbyname(hostname)
    print(hostname, local_ip)
    server = (socket.AF_INET, socket.SOCK_STREAM)
    address = input("enter address  ")
    port = int(input("Enter Port : "))
    server.bind((address, port))
    server.listen()
    print("server listening...")
    connection, address = server.accept()
    print("connected to client...")

    while True:
        data = input("server : ")
        connection.send(bytes(data, 'utf-8'))
        recdata = connection.recv(1024).decode()
        print('client : ', recdata)




def client():
    client = socket()
    address = input("enter address : ")
    port = int(input("Enter Port : "))
    client.connect((address, port))
    print("connected to server..")
    
    while True:
        recdata = client.recv(1024).decode()
        print('server : ', recdata)
        data = input("client: ")
        client.send(bytes(data, 'utf-8'))



